@@ -15,7 +15,7 @@ from codebased.settings import Settings
 from codebased.stats import STATS
 from codebased.tui import Codebased
 
-VERSION = "0.4.22"
+VERSION = "0.5.2"
 
 cli = typer.Typer(
     name="Codebased CLI",
@@ -98,7 +98,7 @@ def search(
             help="Use full-text search.",
         ),
         top_k: int = typer.Option(
-            10,
+            32,
             "-k",
             "--top-k",
             help="Number of results to return.",
@@ -109,6 +109,18 @@ def search(
             "--background/--no-background",
             help="Run in the background.",
         ),
+        rerank: bool = typer.Option(
+            True,
+            "--rerank/--no-rerank",
+            help="Rerank results.",
+        ),
+        radius: float = typer.Option(
+            1.0,
+            "--radius",
+            help="Maximum L2 distance for semantic search.",
+            min=0.0,
+            max=2.0,
+        ),
 ):
     sqlite_version = tuple(map(int, sqlite3.sqlite_version.split('.')))
     if sqlite_version < (3, 34, 0):
@@ -127,7 +139,8 @@ def search(
         semantic=semantic,
         full_text_search=full_text,
         top_k=top_k,
-        rerank=False
+        rerank=rerank,
+        radius=radius
     )
     config = Config(flags=flags)
     settings = Settings.always()
@@ -157,7 +170,7 @@ def search(
     finally:
         dependencies.db.close()
         shutdown_event.set()
-        if thread is not None:
+        if thread is not None and thread.is_alive():
             thread.join()
     if flags.stats:
         print(STATS.dumps())
